from distutils.core import setup
setup(
  name = 'bayle',
  packages = ['bayle'],
  version = '1.0.1',
  description = 'A Python package that provides reproducible code and data for my scientific research',
  author = 'Yann Bayle',
  author_email = 'bayle.yann@live.fr',
  url = 'https://github.com/ybayle/research',
  download_url = 'https://github.com/ybayle/research/archive/v1.0.1.tar.gz',
  keywords = ['satin', 'MIR', 'dataset', 'research', 'reproducibility'],
  classifiers = [],
)
